==> lightdash_client_python-0.621.0-py3-none-any.whl: lightdash_client/models/get_csv_url_response_200_results.py <==
from typing import Any
from typing import Dict
from typing import List
from typing import Type
from typing import TypeVar

import attr

T = TypeVar("T", bound="GetCsvUrlResponse200Results")


@attr.s(auto_attribs=True)
class GetCsvUrlResponse200Results:
    """
    Attributes:
        status (str):
        url (str):
    """

    status: str
    url: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status = self.status
        url = self.url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "status": status,
                "url": url,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status = d.pop("status")

        url = d.pop("url")

        get_csv_url_response_200_results = cls(
            status=status,
            url=url,
        )

        get_csv_url_response_200_results.additional_properties = d
        return get_csv_url_response_200_results

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> lightdash_client_python-0.692.1-py3-none-any.whl: lightdash_client/models/get_csv_url_response_200_results.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="GetCsvUrlResponse200Results")


@attr.s(auto_attribs=True)
class GetCsvUrlResponse200Results:
    """
    Attributes:
        status (str):
        url (str):
    """

    status: str
    url: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status = self.status
        url = self.url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "status": status,
                "url": url,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status = d.pop("status")

        url = d.pop("url")

        get_csv_url_response_200_results = cls(
            status=status,
            url=url,
        )

        get_csv_url_response_200_results.additional_properties = d
        return get_csv_url_response_200_results

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
